BoosTAPro - Heros Devices 0.7.1 documentation

Skip to content
Back to top
View this page

# BoosTAPro

From: Toptica Photonics

Class: `herosdevices.hardware.toptica.dlcpro.BoosTAPro`

Driver Quality Index: beta

Requires the following packages

toptica_lasersdk

Driver for Toptica BoosTAPro tapered amplifier.

Bold arguments are mandatory. For more information on the listed arguments refer to the class documentation: `herosdevices.hardware.toptica.dlcpro.BoosTAPro` If parameters appear in this list but not in the class definition, please recursively check the linked base classes for the definition of the parameter.

Argument | Type | Default Value | Description
--- | --- | --- | ---
address | <class ‘str’> |  | IP address of the laser driver.
frequency | <class ‘float’> |  | Frequency the laser is running on in Hz. Used for interfacing with atomiq. Can be an approximate value if you don’t plan to use this feature.
power | float | None |  | Output power of the laser in W. Used for interfacing with atomiq. Can be an approximate value if you don’t plan to use this feature.
additional_execs | dict | None | None | A dictionary of additional execution commands. The keys are the names of the methods added to the class, the values are arguments for `herosdevices.hardware.toptica.lasersdk.attach_laser_sdk_exec_method`. `{laser_num}` can be used in the `command` string as a placeholder for the laser number specified when initializing the laser source.
additional_queries | dict | None | None | A dictionary of additional queries to the laser. The keys are the names of the attributes added to the class, the values are arguments for `herosdevices.hardware.toptica.lasersdk.LaserSDKCommandQuantity`. `{laser_num}` can be used in the `command` string as a placeholder for the laser number specified when initializing the laser source.
observables | dict | None | None | A set of attributes (like `self.system_health`) that are emitted with the `observable_data` HEROS event. If None, the default observables as defined in `self._default_observables` (which are typically all defined query attributes) are used.

The following JSON strings can be used to start a HERO device representation of `BoosTAPro` using BOSS.

    {
        "_id": "my_BoosTAPro",
        "classname": "herosdevices.hardware.toptica.dlcpro.BoosTAPro",
        "arguments": {
            "address": "192.168.1.24",
            "frequency": 444779044095485.0,
            "power": 0.1,
            "additional_execs": {
                "get_trace": {
                    "command": "{laser_num}:recorder:data:get-data",
                    "expected_args": {
                        "index": "int",
                        "length": "int"
                    },
                    "return_type": "bytes"
                }
            },
            "additional_queries": {
                "scan_enabled": {
                    "command": "{laser_num}:scan:enabled",
                    "dtype": "bool",
                    "observable": true,
                    "writable": true
                }
            },
            "observables": [
                "system_health",
                "emission_status"
            ]
        }
    }

generated from signature